==> plantuml-libs-5.2.0.tgz: package/distribution/simpleicons-5/S/Sanfranciscomunicipalrailway.md <==
# Sanfranciscomunicipalrailway


```text
simpleicons-5/S/Sanfranciscomunicipalrailway
```

```text
include('simpleicons-5/S/Sanfranciscomunicipalrailway')
```



| Illustration | Sanfranciscomunicipalrailway |
| :---: | :---: |
| ![illustration for Illustration](../../simpleicons-5/S/Sanfranciscomunicipalrailway.png) | ![illustration for Sanfranciscomunicipalrailway](../../simpleicons-5/S/Sanfranciscomunicipalrailway.Local.png) |




## Sanfranciscomunicipalrailway

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('simpleicons-5/bootstrap')

' loads the Item which embeds the element Sanfranciscomunicipalrailway
include('simpleicons-5/S/Sanfranciscomunicipalrailway')

' renders the element
Sanfranciscomunicipalrailway('Sanfranciscomunicipalrailway', 'Sanfranciscomunicipalrailway', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('simpleicons-5/bootstrap')

' loads the Item which embeds the element Sanfranciscomunicipalrailway
include('simpleicons-5/S/Sanfranciscomunicipalrailway')

' renders the element
Sanfranciscomunicipalrailway('Sanfranciscomunicipalrailway', 'Sanfranciscomunicipalrailway', 'an optional tech label')
@enduml
```

==> plantuml-libs-6.4.0.tgz: package/distribution/simpleicons-5/S/Sanfranciscomunicipalrailway.md <==
# Sanfranciscomunicipalrailway


```text
simpleicons-5/S/Sanfranciscomunicipalrailway
```

```text
include('simpleicons-5/S/Sanfranciscomunicipalrailway')
```



| Illustration | Sanfranciscomunicipalrailway |
| :---: | :---: |
| ![illustration for Illustration](../../simpleicons-5/S/Sanfranciscomunicipalrailway.png) | ![illustration for Sanfranciscomunicipalrailway](../../simpleicons-5/S/Sanfranciscomunicipalrailway.Local.png) |




## Sanfranciscomunicipalrailway

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('simpleicons-5/bootstrap')

' loads the Item which embeds the element Sanfranciscomunicipalrailway
include('simpleicons-5/S/Sanfranciscomunicipalrailway')

' renders the element
Sanfranciscomunicipalrailway('Sanfranciscomunicipalrailway', 'Sanfranciscomunicipalrailway', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('simpleicons-5/bootstrap')

' loads the Item which embeds the element Sanfranciscomunicipalrailway
include('simpleicons-5/S/Sanfranciscomunicipalrailway')

' renders the element
Sanfranciscomunicipalrailway('Sanfranciscomunicipalrailway', 'Sanfranciscomunicipalrailway', 'an optional tech label')
@enduml
```
